==> aws-cdk.aws-s3-deployment-1.150.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_s3_deployment_ServerSideEncryption(p) {
}
function _aws_cdk_aws_s3_deployment_StorageClass(p) {
}
function _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata(p) {
}
function _aws_cdk_aws_s3_deployment_SourceConfig(p) {
}
function _aws_cdk_aws_s3_deployment_DeploymentSourceContext(p) {
}
function _aws_cdk_aws_s3_deployment_ISource(p) {
}
function _aws_cdk_aws_s3_deployment_BucketDeployment(p) {
}
function _aws_cdk_aws_s3_deployment_Expires(p) {
}
function _aws_cdk_aws_s3_deployment_Source(p) {
}
function _aws_cdk_aws_s3_deployment_CacheControl(p) {
}
function _aws_cdk_aws_s3_deployment_BucketDeploymentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.sources))
        _aws_cdk_aws_s3_deployment_ISource(p.sources);
    if (!visitedObjects.has(p.cacheControl))
        _aws_cdk_aws_s3_deployment_CacheControl(p.cacheControl);
    if (!visitedObjects.has(p.metadata))
        _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata(p.metadata);
    if (!visitedObjects.has(p.serverSideEncryption))
        _aws_cdk_aws_s3_deployment_ServerSideEncryption(p.serverSideEncryption);
    if (!visitedObjects.has(p.storageClass))
        _aws_cdk_aws_s3_deployment_StorageClass(p.storageClass);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_s3_deployment_ServerSideEncryption, _aws_cdk_aws_s3_deployment_StorageClass, _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata, _aws_cdk_aws_s3_deployment_SourceConfig, _aws_cdk_aws_s3_deployment_DeploymentSourceContext, _aws_cdk_aws_s3_deployment_ISource, _aws_cdk_aws_s3_deployment_BucketDeployment, _aws_cdk_aws_s3_deployment_Expires, _aws_cdk_aws_s3_deployment_Source, _aws_cdk_aws_s3_deployment_CacheControl, _aws_cdk_aws_s3_deployment_BucketDeploymentProps };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-s3-deployment-1.151.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_s3_deployment_ServerSideEncryption(p) {
}
function _aws_cdk_aws_s3_deployment_StorageClass(p) {
}
function _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata(p) {
}
function _aws_cdk_aws_s3_deployment_DeploymentSourceContext(p) {
}
function _aws_cdk_aws_s3_deployment_SourceConfig(p) {
}
function _aws_cdk_aws_s3_deployment_ISource(p) {
}
function _aws_cdk_aws_s3_deployment_BucketDeployment(p) {
}
function _aws_cdk_aws_s3_deployment_Expires(p) {
}
function _aws_cdk_aws_s3_deployment_Source(p) {
}
function _aws_cdk_aws_s3_deployment_CacheControl(p) {
}
function _aws_cdk_aws_s3_deployment_BucketDeploymentProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.sources))
        _aws_cdk_aws_s3_deployment_ISource(p.sources);
    if (!visitedObjects.has(p.cacheControl))
        _aws_cdk_aws_s3_deployment_CacheControl(p.cacheControl);
    if (!visitedObjects.has(p.metadata))
        _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata(p.metadata);
    if (!visitedObjects.has(p.serverSideEncryption))
        _aws_cdk_aws_s3_deployment_ServerSideEncryption(p.serverSideEncryption);
    if (!visitedObjects.has(p.storageClass))
        _aws_cdk_aws_s3_deployment_StorageClass(p.storageClass);
    visitedObjects.delete(p);
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_s3_deployment_ServerSideEncryption, _aws_cdk_aws_s3_deployment_StorageClass, _aws_cdk_aws_s3_deployment_UserDefinedObjectMetadata, _aws_cdk_aws_s3_deployment_DeploymentSourceContext, _aws_cdk_aws_s3_deployment_SourceConfig, _aws_cdk_aws_s3_deployment_ISource, _aws_cdk_aws_s3_deployment_BucketDeployment, _aws_cdk_aws_s3_deployment_Expires, _aws_cdk_aws_s3_deployment_Source, _aws_cdk_aws_s3_deployment_CacheControl, _aws_cdk_aws_s3_deployment_BucketDeploymentProps };
module.exports.DeprecationError = DeprecationError;
